@@ -8,7 +8,7 @@ require Exporter;
 *import = \&Exporter::import;
 require DynaLoader;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 #$VERSION = eval $VERSION;
 
 Math::MPFI->DynaLoader::bootstrap($VERSION);
@@ -31,6 +31,9 @@ Math::MPFI->DynaLoader::bootstrap($VERSION);
     use constant  _MATH_MPFI_T    => 11;
     use constant  MPFI_PV_NV_BUG => Math::MPFI::Constant::_has_pv_nv_bug();
 
+    # Inspired by https://github.com/Perl/perl5/issues/19550:
+    use constant ISSUE_19550    => Math::MPFI::Constant::_issue_19550();
+
     use subs qw(MPFI_VERSION_MAJOR MPFI_VERSION_MINOR
                 MPFI_VERSION_PATCHLEVEL MPFI_VERSION_STRING);
 
@@ -213,7 +216,13 @@ sub new {
 
     # $_[0] is the value, $_[1] (if supplied) is the base of the number
     # in the string $[_0].
-    $arg1 = shift;
+    $arg1 = shift; # At this point, an infnan might acquire a POK flag - thus
+                   # assigning to $type a value of 4, instead of 3. Such behaviour also
+                   # turns $arg into a PV and NV dualvar. It's a fairly inconsequential
+                   # bug - https://github.com/Perl/perl5/issues/19550.
+                   # I could workaround this by simply not shifting and re-assigning, but
+                   # I'll leave it as it is - otherwise there's nothing to mark that this
+                   # minor issue (which might also show up in user code) ever existed.
     $base = 0;
 
     $type = _itsa($arg1);
