@@ -79,6 +79,15 @@ _WIN32_BIZARRE_INFNAN    : Defined (on Windows only) when the perl version
 #endif
 #endif
 
+/*
+ * In mpfr-4.1.0, the _Float128 type is exposed in mpfr.h if MPFR_WANT_FLOAT128 is defined.
+ * We fall back to defining it to __float128 if the _Float128 type is unknown.
+*/
+
+#if defined(MPFR_WANT_FLOAT128) && defined(__GNUC__) && !defined(__FLT128_MAX__) && !defined(_BITS_FLOATN_H)
+#define _Float128 __float128
+#endif
+
 #include <mpfi.h>
 #include <mpfi_io.h>
 #include <float.h>
@@ -115,10 +124,33 @@ typedef __float128 float128;
 #  define Newxz(v,n,t) Newz(0,v,n,t)
 #endif
 
+/* A perl bug in perl-5.20 onwards can break &PL_sv_yes and  *
+ * &PL_sv_no. In the overload subs we therefore instead      *
+ * use  SvTRUE_nomg_NN where possible, which is available    *
+ * beginning with perl-5.18.0.                               *
+ * Otherwise we continue using &PL_sv_yes as original        *
+ *                                                           *
+ * See See https://github.com/sisyphus/math-decimal64/pull/1 */
+
+#if defined SvTRUE_nomg_NN
+#define SWITCH_ARGS SvTRUE_nomg_NN(third)
+#else
+#define SWITCH_ARGS third==&PL_sv_yes
+#endif
+
 #ifndef __gmpfr_default_rounding_mode
 #define __gmpfr_default_rounding_mode mpfr_get_default_rounding_mode()
 #endif
 
+#define SV_IS_IOK(x) \
+     SvIOK(x)
+
+#define SV_IS_POK(x) \
+     SvPOK(x)
+
+#define SV_IS_NOK(x) \
+     SvNOK(x)
+
 #define NOK_POK_DUALVAR_CHECK \
         if(SvNOK(b)) { \
          nok_pok++; \
